@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/ed.term.c,v 1.21 1998/04/08 13:58:35 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/ed.term.c,v 1.23 1998/06/27 12:27:07 christos Exp $ */
 /*
  * ed.term.c: Low level terminal interface
  */
@@ -37,7 +37,7 @@
 #include "sh.h"
 #ifndef WINNT
 
-RCSID("$Id: ed.term.c,v 1.21 1998/04/08 13:58:35 christos Exp $")
+RCSID("$Id: ed.term.c,v 1.23 1998/06/27 12:27:07 christos Exp $")
 
 #include "ed.h"
 #include "ed.term.h"
@@ -536,11 +536,12 @@ static struct tcshmodes {
 /* Retry a system call */
 #define RETRY(x) \
    for (;;) \
-	if ((x) == -1) \
+	if ((x) == -1) { \
 	   if (errno != EINTR) \
 	       return -1; \
 	   else \
 	       continue; \
+	} \
 	else \
 	   break \
 
@@ -1121,6 +1122,6 @@ int
 tty_cooked_mode(td)
     void *td;
 {
-    return do_nt_check_cooked_mode()
+    return do_nt_check_cooked_mode();
 }
 #endif /* !WINNT */
