@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/pathnames.h,v 3.16 1996/04/26 19:18:42 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/pathnames.h,v 3.17 1998/09/13 13:51:03 christos Exp $ */
 /*
  * pathnames.h: Location of things to find
  */
@@ -37,6 +37,10 @@
 #ifndef _h_pathnames
 #define _h_pathnames
 
+#ifdef BSD4_4
+# include <paths.h>
+#endif
+
 #if defined(CMUCS) && !defined(_PATH_LOCAL)
 # define _PATH_LOCAL		"/usr/cs/bin"
 #endif /* CMUCS && !_PATH_LOCAL */
