@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.c,v 3.78 1998/04/08 17:57:23 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.c,v 3.83 1998/09/26 12:28:26 christos Exp $ */
 /*
  * sh.c: Main shell routines
  */
@@ -43,10 +43,11 @@ char    copyright[] =
  All rights reserved.\n";
 #endif /* not lint */
 
-RCSID("$Id: sh.c,v 3.78 1998/04/08 17:57:23 christos Exp $")
+RCSID("$Id: sh.c,v 3.83 1998/09/26 12:28:26 christos Exp $")
 
 #include "tc.h"
 #include "ed.h"
+#include "tw.h"
 
 extern bool MapsAreInited;
 extern bool NLSMapsAreInited;
@@ -162,7 +163,9 @@ static	int		  srcfile	__P((char *, bool, int, Char **));
 static	sigret_t	  phup		__P((int));
 static	void		  srcunit	__P((int, bool, int, Char **));
 static	void		  mailchk	__P((void));
+#ifndef _PATH_DEFPATH
 static	Char	 	**defaultpath	__P((void));
+#endif
 static	void		  record	__P((void));
 static	void		  st_save	__P((struct saved_state *, int, int,
 					     Char **, Char **));
@@ -252,7 +255,7 @@ main(argc, argv)
 		t = s;
 	}
 #endif /* WINNT */
-	t = t ? ++t : argv[0];
+	t = t ? t + 1 : argv[0];
 	if (*t == '-') t++;
 	progname = strsave((t && *t) ? t : tcshstr);    /* never want a null */
 	tcsh = strcmp(progname, tcshstr) == 0;
@@ -663,7 +666,11 @@ main(argc, argv)
      * Re-initialize path if set in environment
      */
     if ((tcp = getenv("PATH")) == NULL)
+#ifdef _PATH_DEFPATH
+	importpath(str2short(_PATH_DEFPATH));
+#else /* !_PATH_DEFPATH */
 	setq(STRpath, defaultpath(), &shvhed, VAR_READWRITE);
+#endif /* _PATH_DEFPATH */
     else
 	/* Importpath() allocates memory for the path, and the
 	 * returned pointer from SAVE() was discarded, so
@@ -695,6 +702,11 @@ main(argc, argv)
 	    set(STRshell, Strsave(STR_SHELLPATH), VAR_READWRITE);
     }
 
+#ifdef COLOR_LS_F
+    if ((tcp = getenv("LS_COLORS")) != NULL)
+	parseLS_COLORS(str2short(tcp));
+#endif /* COLOR_LS_F */
+
     doldol = putn((int) getpid());	/* For $$ */
 #ifdef WINNT
     {
@@ -1269,6 +1281,20 @@ main(argc, argv)
 #endif				/* SIG_WINDOW */
     }
 
+    /*
+     * dspkanji/dspmbyte autosetting
+     */
+    /* PATCH IDEA FROM Issei.Suzuki VERY THANKS */
+#if defined(DSPMBYTE)
+    if ((tcp = getenv("LANG")) != NULL && !adrof(CHECK_MBYTEVAR)) {
+	autoset_dspmbyte(str2short(tcp));
+    }
+#if defined(WINNT)
+    else if (!adrof(CHECK_MBYTEVAR))
+      nt_autoset_dspmbyte();
+#endif /* WINNT */
+#endif
+
     /*
      * Now are ready for the -v and -x flags
      */
@@ -2340,6 +2366,7 @@ xexit(i)
     _exit(i);
 }
 
+#ifndef _PATH_DEFPATH
 static Char **
 defaultpath()
 {
@@ -2389,6 +2416,7 @@ defaultpath()
     *blkp = NULL;
     return (blk);
 }
+#endif
 
 static void
 record()
