@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.dir.c,v 3.44 1997/10/27 22:44:25 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.dir.c,v 3.51 1998/09/26 12:28:29 christos Exp $ */
 /*
  * sh.dir.c: Directory manipulation functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.dir.c,v 3.44 1997/10/27 22:44:25 christos Exp $")
+RCSID("$Id: sh.dir.c,v 3.51 1998/09/26 12:28:29 christos Exp $")
 
 /*
  * C Shell - directory management
@@ -53,7 +53,7 @@ static  void 			 dextract	__P((struct directory *));
 static  int 			 skipargs	__P((Char ***, char *, char *));
 static	void			 dgetstack	__P((void));
 
-static struct directory dhead;		/* "head" of loop */
+static struct directory dhead INIT_ZERO_STRUCT;		/* "head" of loop */
 static int    printd;			/* force name to be printed */
 
 int     bequiet = 0;		/* do not print dir stack -strike */
@@ -78,9 +78,9 @@ dinit(hp)
     char    path[MAXPATHLEN];
 
     /* Don't believe the login shell home, because it may be a symlink */
-    tcp = (char *) getwd(path);
+    tcp = (char *) getcwd(path, sizeof(path));
     if (tcp == NULL || *tcp == '\0') {
-	xprintf("%s: %s\n", progname, path);
+	xprintf("%s: %s\n", progname, strerror(errno));
 	if (hp && *hp) {
 	    tcp = short2str(hp);
 	    dstart(tcp);
@@ -514,7 +514,7 @@ dgoto(cp)
 	dp = cp;
 
 #ifdef WINNT
-    cp = SAVE(getwd(NULL));
+    cp = SAVE(getcwd(NULL, 0));
 #else /* !WINNT */
     cp = dcanon(cp, dp);
 #endif /* WINNT */
@@ -539,7 +539,7 @@ dfollow(cp)
 	char *dptr, *ptr;
 	if (chdir(dptr = short2str(cp)) < 0) 
 	    stderror(ERR_SYSTEM, dptr, strerror(errno));
-	else if ((ptr = getwd(ebuf)) && *ptr != '\0') {
+	else if ((ptr = getcwd(ebuf, sizeof(ebuf))) && *ptr != '\0') {
 		xfree((ptr_t) cp);
 		cp = Strsave(str2short(ptr));
 		return dgoto(cp);
@@ -549,7 +549,8 @@ dfollow(cp)
     }
 #endif /* apollo */
 	    
-    (void) strcpy(ebuf, short2str(cp));
+    (void) strncpy(ebuf, short2str(cp), MAXPATHLEN);
+    ebuf[MAXPATHLEN-1] = '\0';
     /*
      * if we are ignoring symlinks, try to fix relatives now.
      * if we are expading symlinks, it should be done by now.
@@ -821,6 +822,12 @@ dcanon(cp, p)
     Char   *newcp;
 #endif /* S_IFLNK */
 
+    /*
+     * kim: if the path given is too long abort().
+     */
+    if (Strlen(cp) >= MAXPATHLEN)
+	abort();
+
     /*
      * christos: if the path given does not start with a slash prepend cwd. If
      * cwd does not start with a slash or the result would be too long abort().
@@ -829,7 +836,7 @@ dcanon(cp, p)
 	Char    tmpdir[MAXPATHLEN];
 
 	p1 = varval(STRcwd);
-	if (p1 == STRNULL || *p1 != '/')
+	if (p1 == STRNULL || ABSOLUTEP(p1))
 	    abort();
 	if (Strlen(p1) + Strlen(cp) + 1 >= MAXPATHLEN)
 	    abort();
@@ -870,11 +877,12 @@ dcanon(cp, p)
 	if (&cp[1] == sp && sp[0] == '.' && sp[1] == '.' && sp[2] == '\0')
 	    slashslash = 1;
 #endif /* apollo */
-	if (*sp == '\0')	/* if component is null */
+	if (*sp == '\0') {	/* if component is null */
 	    if (--sp == cp)	/* if path is one char (i.e. /) */ 
 		break;
 	    else
 		*sp = '\0';
+	}
 	else if (sp[0] == '.' && sp[1] == 0) {
 	    if (slash) {
 		for (p1 = sp, p2 = p + 1; (*p1++ = *p2++) != '\0';)
@@ -898,8 +906,10 @@ dcanon(cp, p)
 	    if (sp != cp && /* symlinks != SYM_IGNORE && */
 		(cc = readlink(short2str(cp), tlink,
 			       sizeof tlink)) >= 0) {
-		(void) Strcpy(link, str2short(tlink));
-		link[cc] = '\0';
+		tlink[cc] = '\0';
+		(void) Strncpy(link, str2short(tlink),
+		    sizeof(link) / sizeof(Char));
+		link[sizeof(link) / sizeof(Char) - 1] = '\0';
 
 		if (slash)
 		    *p = '/';
@@ -987,8 +997,10 @@ dcanon(cp, p)
 	    if (sp != cp && symlinks == SYM_CHASE &&
 		(cc = readlink(short2str(cp), tlink,
 			       sizeof tlink)) >= 0) {
-		(void) Strcpy(link, str2short(tlink));
-		link[cc] = '\0';
+		tlink[cc] = '\0';
+		(void) Strncpy(link, str2short(tlink),
+		    sizeof(link) / sizeof(Char));
+		link[sizeof(link) / sizeof(Char) - 1] = '\0';
 
 		/*
 		 * restore the '/'.
@@ -1096,7 +1108,8 @@ dcanon(cp, p)
 	/*
 	 * Start comparing dev & ino backwards
 	 */
-	p2 = Strcpy(link, cp);
+	p2 = Strncpy(link, cp, sizeof(link) / sizeof(Char));
+	link[sizeof(link) / sizeof(Char) - 1] = '\0';
 	found = 0;
 	while (*p2 && stat(short2str(p2), &statbuf) != -1) {
 	    if (DEV_DEV_COMPARE(statbuf.st_dev, home_dev) &&
