@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.exec.c,v 3.40 1998/04/08 13:58:43 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.exec.c,v 3.44 1998/10/02 10:56:55 christos Exp $ */
 /*
  * sh.exec.c: Search, find, and execute a command!
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.exec.c,v 3.40 1998/04/08 13:58:43 christos Exp $")
+RCSID("$Id: sh.exec.c,v 3.44 1998/10/02 10:56:55 christos Exp $")
 
 #include "tc.h"
 #include "tw.h"
@@ -429,11 +429,7 @@ texec(sf, st)
 
     case ENOEXEC:
 #ifdef WINNT
-	{
-		extern int nt_feed_to_cmd(char *,char**);
-		int rc;
-		rc = nt_feed_to_cmd(f,t);
-	}
+		nt_feed_to_cmd(f,t);
 #endif /* WINNT */
 	/*
 	 * From: casper@fwi.uva.nl (Casper H.S. Dik) If we could not execute
@@ -842,7 +838,7 @@ iscommand(name)
     hashval = havhash ? hashname(name) : 0;
     i = 0;
     do {
-	if (!slash && pv[0][0] == '/' && havhash) {
+	if (!slash && ABSOLUTEP(pv[0]) && havhash) {
 #ifdef FASTHASH
 	    if (!bit(hashval, i))
 		goto cont;
@@ -907,18 +903,23 @@ executable(dir, name, dir_ok)
 #ifdef WINNT
 	{
 	    char *ptr = short2str(path);
-	    char *p2;
+	    char *p2 = ptr;
 	    int has_ext = 0;
-	    p2 = ptr;
-	    while (*ptr) { 
+
+	    while (*ptr++)
+	    	continue;
+
+	    while(ptr > p2) { 
+		if (*ptr == '/')
+		    break;
 		if (*ptr == '.') {
 		    has_ext = 1;
 		    break;
 		}
-		ptr++;
+		ptr--;
 	    }
 	    if (!has_ext && (stat(p2, &stbuf) == -1))
-		catn(path, str2short(".EXE"), MAXPATHLEN);
+		catn(path, ".EXE", MAXPATHLEN);
 	}
 #endif /* WINNT */
 	strname = short2str(path);
@@ -1000,6 +1001,23 @@ tellmewhat(lexp, str)
 	    return TRUE;
 	}
     }
+#ifdef WINNT
+    for (bptr = nt_bfunc; bptr < &nt_bfunc[nt_nbfunc]; bptr++) {
+	if (eq(sp->word, str2short(bptr->bname))) {
+	    if (str == NULL) {
+		if (aliased)
+		    prlex(lexp);
+		xprintf(CGETS(13, 5, "%S: shell built-in command.\n"),
+			      sp->word);
+		flush();
+	    }
+	    else 
+		(void) Strcpy(str, sp->word);
+	    sp->word = s0;	/* we save and then restore this */
+	    return TRUE;
+	}
+    }
+#endif /* WINNT*/
 
     sp->word = cmd = globone(sp->word, G_IGNORE);
 
@@ -1114,6 +1132,17 @@ find_cmd(cmd, prt)
 		return rval;
 	}
     }
+#ifdef WINNT
+    for (bptr = nt_bfunc; bptr < &nt_bfunc[nt_nbfunc]; bptr++) {
+	if (eq(cmd, str2short(bptr->bname))) {
+	    rval = 1;
+	    if (prt)
+		xprintf(CGETS(13, 9, "%S is a shell built-in\n"), cmd);
+	    else
+		return rval;
+	}
+    }
+#endif /* WINNT*/
 
     /* last, look through the path for the command */
 
@@ -1203,4 +1232,15 @@ nodot:
     hashval = hashname(str2short(file));
     bis(hashval, i);
 }
+int hashval_extern(cp)
+	Char *cp;
+{
+	return havhash?hashname(cp):0;
+}
+int bit_extern(val,i)
+	int val;
+	int i;
+{
+	return bit(val,i);
+}
 #endif /* WINNT */
