@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.func.c,v 3.72 1998/04/08 17:57:25 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.func.c,v 3.77 1998/09/18 16:09:11 christos Exp $ */
 /*
  * sh.func.c: csh builtin functions
  */
@@ -36,11 +36,14 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.func.c,v 3.72 1998/04/08 17:57:25 christos Exp $")
+RCSID("$Id: sh.func.c,v 3.77 1998/09/18 16:09:11 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
 #include "tc.h"
+#ifdef WINNT
+#include "nt.const.h"
+#endif /* WINNT */
 
 /*
  * C shell
@@ -115,6 +118,9 @@ isbfunc(t)
 	else
 	    bp1 = bp + 1;
     }
+#ifdef WINNT
+    return nt_check_additional_builtins(cp);
+#endif /*WINNT*/
     return (0);
 }
 
@@ -940,11 +946,12 @@ getword(wp)
 	    c = readc(1);
 	    if (c == '\\' && (c = readc(1)) == '\n')
 		c = ' ';
-	    if (c == '\'' || c == '"')
+	    if (c == '\'' || c == '"') {
 		if (d == 0)
 		    d = c;
 		else if (d == c)
 		    d = 0;
+	    }
 	    if (c < 0)
 		goto past;
 	    if (wp) {
@@ -1307,6 +1314,14 @@ dosetenv(v, c)
     }
 #endif /* apollo */
 
+    /* dspkanji/dspmbyte autosetting */
+    /* PATCH IDEA FROM Issei.Suzuki VERY THANKS */
+#if defined(DSPMBYTE)
+    if(eq(vp, STRLANG) && !adrof(CHECK_MBYTEVAR)) {
+	autoset_dspmbyte(lp);
+    }
+#endif
+
     if (islocale_var(vp)) {
 #ifdef NLS
 	int     k;
@@ -1360,11 +1375,11 @@ dosetenv(v, c)
 	xfree((ptr_t) lp);
 	return;
     }
-    if (eq(vp, STRNTonlystartexes)) {
+    if (eq(vp, STRtcshonlystartexes)) {
 	__nt_only_start_exes = 1;
 	xfree((ptr_t) lp);
 	return;
-    }
+	}
 #endif /* WINNT */
     if (eq(vp, STRKTERM)) {
 	char *t;
@@ -1408,6 +1423,13 @@ dosetenv(v, c)
 	return;
     }
 
+#ifdef COLOR_LS_F
+    if (eq(vp, STRLS_COLORS)) {
+        parseLS_COLORS(lp);
+	return;
+    }
+#endif /* COLOR_LS_F */
+
 #ifdef SIG_WINDOW
     /*
      * Load/Update $LINES $COLUMNS
@@ -1529,10 +1551,14 @@ dounsetenv(v, c)
 		    nls_dll_unload();
 		    nlsinit();
 		}
-		else if (eq(name,(STRNTonlystartexes))) {
+		else if (eq(name,(STRtcshonlystartexes))) {
 			__nt_only_start_exes = 0;
 		}
 #endif /* WINNT */
+#ifdef COLOR_LS_F
+		else if (eq(name, STRLS_COLORS))
+		    parseLS_COLORS(n);
+#endif /* COLOR_LS_F */
 		/*
 		 * start again cause the environment changes
 		 */
@@ -1601,6 +1627,9 @@ Unsetenv(name)
     register Char *cp, *dp;
     Char **oep = ep;
 
+#ifdef WINNT
+	nt_set_env(name,NULL);
+#endif /*WINNT */
     for (; *ep; ep++) {
 	for (cp = name, dp = *ep; *cp && *cp == *dp; cp++, dp++)
 	    continue;
@@ -2299,10 +2328,19 @@ struct command *c;
 		++b;
 	    }
 	}
-	if (Tty_raw_mode)
-	    xputchar('\r');
-	xputchar('\n');
+	if (row < (rows - 1)) {
+	    if (Tty_raw_mode)
+		xputchar('\r');
+	    xputchar('\n');
+	}
     }
+#ifdef WINNT
+    nt_print_builtins(maxwidth);
+#else
+    if (Tty_raw_mode)
+	xputchar('\r');
+    xputchar('\n');
+#endif /* WINNT */
 
     lbuffed = 1;		/* turn back on line buffering */
     flush();
