@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.glob.c,v 3.38 1996/04/26 19:19:30 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.glob.c,v 3.42 1998/04/08 17:57:27 christos Exp $ */
 /*
  * sh.glob.c: Regular expression expansion
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.glob.c,v 3.38 1996/04/26 19:19:30 christos Exp $")
+RCSID("$Id: sh.glob.c,v 3.42 1998/04/08 17:57:27 christos Exp $")
 
 #include "tc.h"
 
@@ -77,6 +77,7 @@ static int pargc = 0;
  *
  */
 static	Char	 *globtilde	__P((Char **, Char *));
+static	Char     *handleone	__P((Char *, Char **, int));
 static	Char	**libglob	__P((Char **));
 static	Char	**globexpand	__P((Char **));
 static	int	  globbrace	__P((Char *, Char *, Char ***));
@@ -629,7 +630,7 @@ ginit()
 void
 rscan(t, f)
     register Char **t;
-    void    (*f) ();
+    void    (*f) __P((int));
 {
     register Char *p;
 
@@ -866,6 +867,10 @@ backeval(cp, literal)
 	    c = (*ip++ & TRIM);
 	    if (c == 0)
 		break;
+#ifdef WINNT
+	    if (c == '\r')
+	    	c = ' ';
+#endif /* WINNT */
 	    if (c == '\n') {
 		/*
 		 * Continue around the loop one more time, so that we can eat
@@ -1038,8 +1043,8 @@ pmatch(string, pattern, estr)
 		if (match)
 		    continue;
 		if (rangec == '-' && *(pattern-2) != '[' && *pattern  != ']') {
-		    match = (stringc <= (*pattern & TRIM) &&
-			      (*(pattern-2) & TRIM) <= stringc);
+		    match = (globcharcoll(stringc, *pattern & TRIM) <= 0 &&
+		    globcharcoll(*(pattern-2) & TRIM, stringc) <= 0);
 		    pattern++;
 		}
 		else 
