@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.h,v 3.79 1998/04/08 17:57:28 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.h,v 3.85 1998/09/18 16:09:13 christos Exp $ */
 /*
  * sh.h: Catch it all globals and includes file!
  */
@@ -58,8 +58,8 @@
 #ifndef WINNT
 # define INIT_ZERO
 # define INIT_ZERO_STRUCT
+# define force_read read
 #endif /*!WINNT */
-
 /*
  * Sanity
  */
@@ -77,9 +77,11 @@
 
 #ifdef SHORT_STRINGS
 typedef short Char;
+typedef unsigned short uChar;
 # define SAVE(a) (Strsave(str2short(a)))
 #else
 typedef char Char;
+typedef unsigned char uChar;
 # define SAVE(a) (strsave(a))
 #endif 
 
@@ -108,7 +110,8 @@ typedef int sigret_t;
 #ifndef WINNT
 # define ABSOLUTEP(p)	(*(p) == '/')
 #else /* WINNT */
-# define ABSOLUTEP(p)	((p)[0] != '\0' && (p)[1] == ':' && (p)[2] == '/')
+# define ABSOLUTEP(p)	((p)[0] == '/' || \
+			 (Isalpha((p)[0]) && (p)[1] == ':' && (p)[2] == '/'))
 #endif /* WINNT */
 
 /*
@@ -265,7 +268,7 @@ typedef int sigret_t;
  * redefines malloc(), so we define the following
  * to avoid it.
  */
-# ifdef linux
+# if defined(linux) || defined(sgi)
 #  define NO_FIX_MALLOC
 #  include <stdlib.h>
 # else /* linux */
@@ -279,7 +282,7 @@ typedef int sigret_t;
 #  undef free
 #  undef calloc
 #  undef realloc
-# endif /* linux */
+# endif /* linux || sgi */
 # include <limits.h>
 #endif /* POSIX && !WINNT */
 
@@ -921,6 +924,10 @@ extern struct biltins {
     int     minargs, maxargs;
 } bfunc[];
 extern int nbfunc;
+#ifdef WINNT
+extern struct biltins  nt_bfunc[];
+extern int nt_nbfunc;
+#endif /* WINNT*/
 
 extern struct srch {
     char   *s_name;
@@ -1177,7 +1184,13 @@ extern int errno, sys_nerr;
    nl_catd catopen __P((const char *, int));
    int catclose __P((nl_catd));
 #  else
+#   ifdef __uxps__
+#    define gettxt gettxt_ds
+#   endif
 #   include <nl_types.h>
+#   ifdef __uxps__
+#    undef gettxt
+#   endif
 #  endif
 #  ifndef MCLoadBySet
 #   define MCLoadBySet 0
