@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.init.c,v 3.44 1998/04/08 13:58:51 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.init.c,v 3.46 1998/07/07 12:06:23 christos Exp $ */
 /*
  * sh.init.c: Function and signal tables
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.init.c,v 3.44 1998/04/08 13:58:51 christos Exp $")
+RCSID("$Id: sh.init.c,v 3.46 1998/07/07 12:06:23 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -72,15 +72,9 @@ struct	biltins bfunc[] = {
     { "case",		dozip,		0,	1	},
     { "cd",		dochngd,	0,	INF	},
     { "chdir",		dochngd,	0,	INF	},
-#ifdef WINNT
-    { "cls",		docls,		0,	0	},
-#endif /* WINNT */
     { "complete",	docomplete,	0,	INF	},
     { "continue",	docontin,	0,	0	},
     { "default",	dozip,		0,	0	},
-#ifdef NTDBG
-    { "debugbreak",	dodebugbreak,	0,	0	},
-#endif /* NTDBG */
     { "dirs",		dodirs,		0,	INF	},
 #if defined(_CRAY) && !defined(_CRAYMPP)
     { "dmmode",		dodmmode,	0,	1	},
@@ -158,17 +152,11 @@ struct	biltins bfunc[] = {
 #endif /* TCF */
     { "shift",		shift,		0,	1	},
     { "source",		dosource,	1,	INF	},
-#ifdef WINNT
-    { "start",		dostart,	1,	INF	},
-#endif /* WINNT */
     { "stop",		dostop,		1,	INF	},
     { "suspend",	dosuspend,	0,	0	},
     { "switch",		doswitch,	1,	INF	},
     { "telltc",		dotelltc,	0,	INF	},
     { "time",		dotime,		0,	INF	},
-#ifdef WINNT
-    { "title",		dotitle,	1,	INF	},
-#endif /* WINNT */
 #if defined(_CX_UX)
     { "ucb",		doucb,		0,	INF	},
 #endif /* _CX_UX */
