@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.print.c,v 3.11 1998/04/08 17:57:30 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.print.c,v 3.15 1998/09/09 10:29:21 christos Exp $ */
 /*
  * sh.print.c: Primitive Output routines.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.print.c,v 3.11 1998/04/08 17:57:30 christos Exp $")
+RCSID("$Id: sh.print.c,v 3.15 1998/09/09 10:29:21 christos Exp $")
 
 #include "ed.h"
 
@@ -194,7 +194,7 @@ draino()
 void
 flush()
 {
-    register int unit;
+    int unit;
     static int interrupted = 0;
     size_t sz;
 
@@ -225,9 +225,35 @@ flush()
 #endif
 #endif
     sz = (size_t) (linp - linbuf);
-    if (write(unit, linbuf, sz) != sz && !haderr)
-	/* XXX: This ends up to cause an infinite loop if we lose our tty */
-	stderror(ERR_SILENT);
+    if (write(unit, linbuf, sz) == -1)
+	switch (errno) {
+#ifdef EIO
+	/* We lost our tty */
+	case EIO:
+#endif
+#ifdef ENXIO
+	/*
+	 * Deal with Digital Unix 4.0D bogocity, returning ENXIO when
+	 * we lose our tty.
+	 */
+	case ENXIO:
+#endif
+	/*
+	 * IRIX 6.4 bogocity?
+	 */
+#ifdef ENOTTY
+	case ENOTTY:
+#endif
+#ifdef EBADF
+	case EBADF:
+#endif
+	/* Nothing to do, but die */
+	    xexit(1);
+	    break;
+	default:
+	    stderror(ERR_SILENT);
+	    break;
+	}
 
     linp = linbuf;
     interrupted = 0;
