@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.proc.c,v 3.67 1998/04/08 13:58:57 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.proc.c,v 3.69 1998/06/27 12:27:23 christos Exp $ */
 /*
  * sh.proc.c: Job manipulations
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.proc.c,v 3.67 1998/04/08 13:58:57 christos Exp $")
+RCSID("$Id: sh.proc.c,v 3.69 1998/06/27 12:27:23 christos Exp $")
 
 #include "ed.h"
 #include "tc.h"
@@ -777,7 +777,7 @@ static void
 pclrcurr(pp)
     register struct process *pp;
 {
-    if (pp == pcurrent)
+    if (pp == pcurrent) {
 	if (pprevious != NULL) {
 	    pcurrent = pprevious;
 	    pprevious = pgetcurr(pp);
@@ -786,6 +786,7 @@ pclrcurr(pp)
 	    pcurrent = pgetcurr(pp);
 	    pprevious = pgetcurr(pp);
 	}
+    }
     else if (pp == pprevious)
 	pprevious = pgetcurr(pp);
 }
@@ -1125,13 +1126,14 @@ pprint(pp, flag)
 		    format = "%-30s";
 		else
 		    format = "%s";
-		if (pstatus == status)
+		if (pstatus == status) {
 		    if (pp->p_reason == reason) {
 			xprintf(format, "");
 			goto prcomd;
 		    }
 		    else
 			reason = (int) pp->p_reason;
+		}
 		else {
 		    status = pstatus;
 		    reason = (int) pp->p_reason;
@@ -1169,11 +1171,12 @@ pprint(pp, flag)
 
 		case PNEXITED:
 		case PAEXITED:
-		    if (flag & REASON)
+		    if (flag & REASON) {
 			if (pp->p_reason)
 			    xprintf(CGETS(17, 6, "Exit %-25d"), pp->p_reason);
 			else
 			    xprintf(format, CGETS(17, 7, "Done"));
+		    }
 		    break;
 
 		default:
@@ -1646,7 +1649,11 @@ pkill(v, signum)
 	else if (!(Isdigit(*cp) || *cp == '-'))
 	    stderror(ERR_NAME | ERR_JOBARGS);
 	else {
+#ifndef WINNT
 	    pid = atoi(short2str(cp));
+#else
+		pid = strtoul(short2str(cp),NULL,0);
+#endif /* WINNT */
 	    if (kill(pid, signum) < 0) {
 		xprintf("%d: %s\n", pid, strerror(errno));
 		err1++;
