@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.sem.c,v 3.43 1998/04/08 13:58:59 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.sem.c,v 3.46 1998/09/04 21:16:56 christos Exp $ */
 /*
  * sh.sem.c: I/O redirections and job forking. A touchy issue!
  *	     Most stuff with builtins is incorrect
@@ -37,10 +37,13 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.sem.c,v 3.43 1998/04/08 13:58:59 christos Exp $")
+RCSID("$Id: sh.sem.c,v 3.46 1998/09/04 21:16:56 christos Exp $")
 
 #include "tc.h"
 #include "tw.h"
+#ifdef WINNT
+#include "nt.const.h"
+#endif /*WINNT*/
 
 #ifdef CLOSE_ON_EXEC
 # ifndef SUNOS4
@@ -113,6 +116,21 @@ execute(t, wanttty, pipein, pipeout)
     if (t == 0) 
 	return;
 
+#ifdef WINNT
+    {
+        if ((varval(STRNTslowexec) != STRNULL) &&
+            !t->t_dcdr && !t->t_dcar && !t->t_dflg && !didfds &&
+            (intty || intact) && (t->t_dtyp == NODE_COMMAND) &&
+	    !isbfunc(t)) {
+	    if ((t->t_dcom[0][0] & (QUOTE | TRIM)) == QUOTE)
+		(void) Strcpy(t->t_dcom[0], t->t_dcom[0] + 1);
+	    Dfix(t);
+            if (nt_try_fast_exec(t) == 0)
+                return;
+        }
+    }
+#endif /* WINNT */
+
     /*
      * Ed hutchins@sgi.com & Dominic dbg@sgi.com
      * Sat Feb 25 03:13:11 PST 1995
@@ -210,9 +228,9 @@ execute(t, wanttty, pipein, pipeout)
 	 * parsed.
 	 */
 	while (t->t_dtyp == NODE_COMMAND)
-	    if (eq(t->t_dcom[0], STRnice))
-		if (t->t_dcom[1])
-		    if (strchr("+-", t->t_dcom[1][0]))
+	    if (eq(t->t_dcom[0], STRnice)) {
+		if (t->t_dcom[1]) {
+		    if (strchr("+-", t->t_dcom[1][0])) {
 			if (t->t_dcom[2]) {
 			    setname("nice");
 			    t->t_nice =
@@ -222,34 +240,40 @@ execute(t, wanttty, pipein, pipeout)
 			}
 			else
 			    break;
+		    }
 		    else {
 			t->t_nice = 4;
 			lshift(t->t_dcom, 1);
 			t->t_dflg |= F_NICE;
 		    }
+		}
 		else
 		    break;
-	    else if (eq(t->t_dcom[0], STRnohup))
+	    }
+	    else if (eq(t->t_dcom[0], STRnohup)) {
 		if (t->t_dcom[1]) {
 		    t->t_dflg |= F_NOHUP;
 		    lshift(t->t_dcom, 1);
 		}
 		else
 		    break;
-	    else if (eq(t->t_dcom[0], STRhup))
+	    }
+	    else if (eq(t->t_dcom[0], STRhup)) {
 		if (t->t_dcom[1]) {
 		    t->t_dflg |= F_HUP;
 		    lshift(t->t_dcom, 1);
 		}
 		else
 		    break;
-	    else if (eq(t->t_dcom[0], STRtime))
+	    }
+	    else if (eq(t->t_dcom[0], STRtime)) {
 		if (t->t_dcom[1]) {
 		    t->t_dflg |= F_TIME;
 		    lshift(t->t_dcom, 1);
 		}
 		else
 		    break;
+	    }
 #ifdef F_VER
 	    else if (eq(t->t_dcom[0], STRver))
 		if (t->t_dcom[1] && t->t_dcom[2]) {
