@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.const.c,v 3.44 1998/04/08 13:59:04 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.const.c,v 3.48 1998/09/18 16:09:16 christos Exp $ */
 /*
  * sh.const.c: String constants for tcsh.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.const.c,v 3.44 1998/04/08 13:59:04 christos Exp $")
+RCSID("$Id: tc.const.c,v 3.48 1998/09/18 16:09:16 christos Exp $")
 
 Char STRlogout[]	= { 'l', 'o', 'g', 'o', 'u', 't', '\0' };
 Char STRautologout[]	= { 'a', 'u', 't', 'o', 'l', 'o', 'g', 'o', 'u', 't', 
@@ -113,6 +113,49 @@ Char STRtildothist[]	= { '~', '/', '.', 'h', 'i', 's', 't', 'o', 'r',
 
 #ifdef KANJI
 Char STRnokanji[]	= { 'n', 'o', 'k', 'a', 'n', 'j', 'i', '\0' };
+# ifdef DSPMBYTE
+Char STRdspmbyte[]	= { 'd', 's', 'p', 'm', 'b', 'y', 't', 'e', '\0' };
+# endif
+# if defined(DSPMBYTE)
+Char STRKEUC[]		= { 'e', 'u', 'c', '\0' };
+Char STRKSJIS[]		= { 's', 'j', 'i', 's', '\0' };
+#  ifdef MBYTEDEBUG	/* Sorry, use for beta testing */
+Char STRmbytemap[]	= { 'm', 'b', 'y', 't', 'e', 'm', 'a', 'p', '\0' };
+#  endif /* MBYTEMAP */
+/* PATCH IDEA FROM Issei.Suzuki VERY THANKS */
+/* dspmbyte autoset trap */
+/* STRLANGEUC,STRLANGEUCB = EUC Trap */
+/* STRLANGSJIS,STRLANGSJISB = SJIS Trap */
+#  if defined(__FreeBSD__) || defined(__uxps__) || defined(linux) || defined(sgi) /* linux? */
+Char STRLANGEUC[]	= { 'j', 'a', '_', 'J', 'P', '.', 'E', 'U', 'C', '\0' };
+#   if defined(__uxps__)
+Char STRLANGEUCB[]	= { 'j', 'a', 'p', 'a', 'n', '\0' };
+#   elif defined(linux)
+Char STRLANGEUCB[]	= { 'j', 'a', '_', 'J', 'P', '.', 'u', 'j', 'i', 's',
+			    '\0' };
+#   else
+Char STRLANGEUCB[]	= { '\0' };
+#   endif
+Char STRLANGSJIS[]	= { 'j', 'a', '_', 'J', 'P', '.', 'S', 'J', 'I', 'S',
+			    '\0' };
+Char STRLANGSJISB[]	= { '\0' };
+#  elif defined(__uxpm__)
+Char STRLANGEUC[]	= { 'j', 'a', 'p', 'a', 'n', '\0' };
+Char STRLANGEUCB[]	= { '\0' };
+Char STRLANGSJIS[]	= { '\0' };
+Char STRLANGSJISB[]	= { '\0' };
+#  elif defined(SOLARIS2)
+Char STRLANGEUC[]	= { 'j', 'a', '\0' };
+Char STRLANGEUCB[]	= { 'j', 'a', 'p', 'a', 'n', 'e', 's', 'e', '\0' };
+Char STRLANGSJIS[]	= { '\0' };
+Char STRLANGSJISB[]	= { '\0' };
+#  else
+Char STRLANGEUC[]	= { '\0' };
+Char STRLANGEUCB[]	= { '\0' };
+Char STRLANGSJIS[]	= { '\0' };
+Char STRLANGSJISB[]	= { '\0' };
+#  endif
+# endif /* defined(DSPMBYTE) */
 #endif
 
 Char STRtildotdirs[]	= { '~', '/', '.', 'c', 's', 'h', 'd', 'i', 'r',
@@ -254,19 +297,6 @@ Char STRerase[]		= { 'e', 'r', 'a', 's', 'e', '\0' };
 Char STRprev[]		= { 'p', 'r', 'e', 'v', '\0' };
 Char STRcomplete[]	= { 'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', '\0' };
 Char STRenhance[]	= { 'e', 'n', 'h', 'a', 'n', 'c', 'e', '\0' };
-#ifdef WINNT
-Char STRigncase[]	= { 'i', 'g', 'n', 'c', 'a', 's', 'e', '\0' };
-Char STRoldtitle[]	= { 'o', 'l', 'd', 't', 'i', 't', 'l', 'e', '\0' };
-Char STRNTlamepathfix[] = { 'N', 'T', 'l', 'a', 'm', 'e', 'p', 'a', 't', 'h',
-			    'f', 'i','x','\0'};
-Char STRNTlameargfix[]  = { 'N', 'T', 'l', 'a', 'm', 'e', 'a', 'r', 'g', 'f',
-			    'i', 'x', '\0' };
-Char STRtcshlang[]	= { 'T', 'C', 'S', 'H', 'L', 'A', 'N', 'G', '\0' };
-Char STRtcshsubsthb[]	= { 'T', 'C', 'S', 'H', 'S', 'U', 'B', 'S', 'T',
-			    'H', 'B', '\0' };
-Char STRNTonlystartexes[]={ 'N', 'T', 'O', 'N', 'L', 'Y', 'S', 'T', 'A', 'R',
-			    'T', 'E', 'X', 'E', 'S', '\0' };
-#endif /* WINNT */
 Char STRautoexpand[]	= { 'a', 'u', 't', 'o', 'e', 'x', 'p', 'a', 'n', 'd',
 			    '\0' };
 Char STRautocorrect[]	= { 'a', 'u', 't', 'o', 'c', 'o', 'r', 'r', 'e', 'c',
@@ -346,6 +376,14 @@ Char STRver[]		= { 'v', 'e', 'r', '\0' };
 Char STRwarnebcdic[]    = { 'w', 'a', 'r', 'n', 'e', 'b', 'c', 'd', 'i', 'c', '\0' };
 #endif
 
+#ifdef COLOR_LS_F
+Char STRls[]		= { 'l', 's', '\0' };
+Char STRlsmF[]		= { 'l', 's', '-', 'F', '\0' };
+Char STRcolor[]		= { 'c', 'o', 'l', 'o', 'r', '\0' };
+Char STRmmcolormauto[]	= {'-', '-', 'c', 'o', 'l', 'o', 'r', '=', 'a', 'u', 't', 'o', '\0' };
+Char STRLS_COLORS[]	= { 'L', 'S', '_', 'C', 'O', 'L', 'O', 'R', 'S', '\0' };
+#endif /* COLOR_LS_F */
+
 Char STRup[]		= { 'u', 'p', '\0' };
 Char STRdown[]		= { 'd', 'o', 'w', 'n', '\0' };
 Char STRleft[]		= { 'l', 'e', 'f', 't', '\0' };
