@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.func.c,v 3.74 1998/04/08 13:59:06 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.func.c,v 3.80 1998/09/18 15:31:49 christos Exp $ */
 /*
  * tc.func.c: New tcsh builtins.
  */
@@ -36,12 +36,15 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.func.c,v 3.74 1998/04/08 13:59:06 christos Exp $")
+RCSID("$Id: tc.func.c,v 3.80 1998/09/18 15:31:49 christos Exp $")
 
 #include "ed.h"
 #include "ed.defns.h"		/* for the function names */
 #include "tw.h"
 #include "tc.h"
+#ifdef WINNT
+#include "nt.const.h"
+#endif /* WINNT */
 
 #ifdef AFS
 #define PASSMAX 16
@@ -210,6 +213,9 @@ dolist(v, c)
 {
     int     i, k;
     struct stat st;
+#ifdef COLOR_LS_F
+    extern bool color_context_ls;
+#endif /* COLOR_LS_F */
 
     USE(c);
     if (*++v == NULL) {
@@ -288,6 +294,15 @@ dolist(v, c)
 	nextword->word = Strsave(STRmCF);
 	lastword->next = nextword;
 	nextword->prev = lastword;
+#ifdef COLOR_LS_F
+	if (color_context_ls) {
+	    lastword = nextword;
+	    nextword = (struct wordent *) xcalloc(1, sizeof cmd);
+	    nextword->word = Strsave(STRmmcolormauto);
+	    lastword->next = nextword;
+	    nextword->prev = lastword;
+	}
+#endif /* COLOR_LS_F */
 	lastword = nextword;
 	for (cp = *v; cp; cp = *++v) {
 	    nextword = (struct wordent *) xcalloc(1, sizeof cmd);
@@ -351,7 +366,7 @@ dolist(v, c)
 	    }
 	    else if (
 #ifdef WINNT
-		((char)tmp[1] != ':') ||
+		((char)tmp[1] == ':') ||
 		(is_unc) ||
 #endif /* WINNT */
 		S_ISDIR(st.st_mode)) {
@@ -577,7 +592,7 @@ find_stop_ed()
 
 	    p = short2str(pp->p_command);
 	    /* get the first word */
-	    for (cp = p; *cp && !isspace(*cp); cp++)
+	    for (cp = p; *cp && !isspace((unsigned char) *cp); cp++)
 		continue;
 	    *cp = '\0';
 		
@@ -1163,13 +1178,13 @@ rmstar(cp)
 		    xprintf(CGETS(22, 8,
 			    "Do you really want to delete all files? [n/y] "));
 		    flush();
-		    (void) read(SHIN, &c, 1);
+		    (void) force_read(SHIN, &c, 1);
 		    /* 
 		     * Perhaps we should use the yesexpr from the
 		     * actual locale
 		     */
 		    doit = (strchr(CGETS(22, 14, "Yy"), c) != NULL);
-		    while (c != '\n' && read(SHIN, &c, 1) == 1)
+		    while (c != '\n' && force_read(SHIN, &c, 1) == 1)
 			continue;
 		    if (!doit) {
 			/* remove the command instead */
@@ -1945,7 +1960,7 @@ hashbang(fd, vp)
 	    }
 	    sargv[sargc] = NULL;
 	    ws = NULL;
-	    if (sargc > 0)
+	    if (sargc > 0) {
 		*vp = blk2short(sargv);
 		return 0;
 	    }
@@ -1989,44 +2004,57 @@ getremotehost()
     struct hostent* hp;
     struct sockaddr_in saddr;
     int len = sizeof(struct sockaddr_in);
+#if defined(UTHOST) && !defined(HAVENOUTMP)
+    char *sptr = NULL;
+#endif
 
     if (getpeername(SHIN, (struct sockaddr *) &saddr, &len) != -1) {
+#if 0
 	if ((hp = gethostbyaddr((char *)&saddr.sin_addr, sizeof(struct in_addr),
 				AF_INET)) != NULL)
 	    host = hp->h_name;
 	else
+#endif
 	    host = inet_ntoa(saddr.sin_addr);
     }
 #if defined(UTHOST) && !defined(HAVENOUTMP)
     else {
-	char *ptr, *sptr;
+	char *ptr;
 	char *name = utmphost();
 	/* Avoid empty names and local X displays */
 	if (name != NULL && *name != '\0' && *name != ':') {
 	    /* Look for host:display.screen */
 	    if ((sptr = strchr(name, ':')) != NULL)
 		*sptr = '\0';
-	    if (sptr != name) {
-		if ((hp = gethostbyname(name)) == NULL) {
-		    /* Try again eliminating the trailing domain */
-		    if ((ptr = strchr(name, '.')) != NULL) {
-			*ptr = '\0';
-			if ((hp = gethostbyname(name)) != NULL)
-			    host = hp->h_name;
-			*ptr = '.';
+	    /* Leave IP address as is */
+	    if (isdigit(*name))
+		host = name;
+	    else {
+		if (sptr != name) {
+		    if ((hp = gethostbyname(name)) == NULL) {
+			/* Try again eliminating the trailing domain */
+			if ((ptr = strchr(name, '.')) != NULL) {
+			    *ptr = '\0';
+			    if ((hp = gethostbyname(name)) != NULL)
+				host = hp->h_name;
+			    *ptr = '.';
+			}
 		    }
+		    else
+			host = hp->h_name;
 		}
-		else
-		    host = hp->h_name;
 	    }
-	    if (sptr)
-		*sptr = ':';
 	}
     }
 #endif
 
     if (host)
 	tsetenv(STRREMOTEHOST, str2short(host));
+
+#if defined(UTHOST) && !defined(HAVENOUTMP)
+    if (sptr)
+	*sptr = ':';
+#endif
 }
 
 
