@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.os.h,v 3.72 1998/04/08 17:57:33 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.os.h,v 3.79 1998/09/26 12:28:33 christos Exp $ */
 /*
  * tc.os.h: Shell os dependent defines
  */
@@ -502,13 +502,10 @@ struct ucred {
 #endif /* POSIX */
 
 
-#if SYSVREL > 0 && !defined(OREO) && !defined(sgi) && !defined(linux) && !defined(sinix)
-# define NEEDgetwd
-#endif /* SYSVREL > 0 && !OREO && !sgi && !linux && !sinix */
-
-#if defined(SOLARIS2) || defined(sinix)
-# undef NEEDgetwd
-# define getwd(a)	getcwd(a, MAXPATHLEN)
+#if !defined(SOLARIS2) && !defined(sinix) && !defined(BSD4_4) && !defined(WIN32)
+# if (SYSVREL > 0 && !defined(OREO) && !defined(sgi) && !defined(linux) && !defined(sinix) && !defined(_AIX)) || defined(NeXT)
+#  define NEEDgetcwd
+# endif /* (SYSVREL > 0 && !OREO && !sgi && !linux && !sinix && !IBMAIX) || NeXT */
 #endif
 
 #ifndef S_IFLNK
@@ -530,9 +527,11 @@ typedef struct timeval timeval_t;
 # define free tcsh_free
 #endif /* NeXT */
 
+#if !defined(BSD4_4) && !defined(__linux__) &&!defined(__hpux)
 #ifndef NEEDgethostname
 extern int gethostname __P((char *, int));
 #endif /* NEEDgethostname */
+#endif /* !BDS4_4 && !__linux__ && !__hpux */
 
 #if !defined(POSIX) || defined(SUNOS4) || defined(UTekV) || defined(sysV88)
 extern time_t time();
@@ -573,7 +572,7 @@ extern void perror();
 #endif
 
 # ifdef BSDSIGS
-#  if defined(_AIX370) || defined(MACH) || defined(NeXT) || defined(_AIXPS2) || defined(ardent) || defined(SUNOS4) || defined(HPBSD)
+#  if defined(_AIX370) || defined(MACH) || defined(NeXT) || defined(_AIXPS2) || defined(ardent) || defined(SUNOS4) || defined(HPBSD) || defined(__MACHTEN__)
 extern int sigvec();
 extern int sigpause();
 #  else	/* !(_AIX370 || MACH || NeXT || _AIXPS2 || ardent || SUNOS4 || HPBSD) */
@@ -621,9 +620,13 @@ extern int strcoll();
 
 # ifdef BSDJOBS
 #  ifdef BSDTIMES
+#   ifdef __MACHTEN__
+extern pid_t wait3();
+#   else
 #   ifndef HPBSD
 extern int wait3();
 #   endif /* HPBSD */
+#   endif /* __MACHTEN__ */
 #  else	/* !BSDTIMES */
 #   if !defined(POSIXJOBS) && !defined(_SEQUENT_)
 extern int wait3();
@@ -660,14 +663,14 @@ extern struct authorization *getauthuid();
 #  endif /* PW_AUTH */
 # endif /* __STDC__ */
 
-# ifndef getwd
-extern char *getwd();
-# endif	/* getwd */
+# ifndef getcwd
+extern char *getcwd();
+# endif	/* getcwd */
 
 #else /* POSIX || !SUNOS4 || !UTekV || !sysV88 */
 
 # if (defined(SUNOS4) && !defined(__GNUC__)) || defined(_IBMR2) || defined(_IBMESA)
-extern char *getwd();
+extern char *getvwd();
 # endif	/* (SUNOS4 && ! __GNUC__) || _IBMR2 || _IBMESA */
 
 # ifdef SCO
@@ -742,7 +745,6 @@ extern char *sbrk __P((ssize_t));
 extern int ioctl __P((int, unsigned long, char *));
 extern pid_t vfork __P((void));
 extern int killpg __P((pid_t, int));
-extern char *getwd __P((char *));
 #endif /* __osf__ && __alpha && DECOSF1 < 200 */
 
 #endif /* _h_tc_os */
