@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.printf.c,v 3.15 1996/04/26 19:21:18 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.printf.c,v 3.18 1998/04/08 17:57:34 christos Exp $ */
 /*
  * tc.printf.c: A public-domain, minimal printf/sprintf routine that prints
  *	       through the putchar() routine.  Feel free to use for
@@ -38,7 +38,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.printf.c,v 3.15 1996/04/26 19:21:18 christos Exp $")
+RCSID("$Id: tc.printf.c,v 3.18 1998/04/08 17:57:34 christos Exp $")
 
 #ifdef lint
 #undef va_arg
@@ -125,7 +125,7 @@ doprnt(addchar, sfmt, ap)
 	    }
 
 	    fmt = (unsigned char) *f;
-	    if (fmt != 'S' && Isupper(fmt)) {
+	    if (fmt != 'S' && fmt != 'Q' && Isupper(fmt)) {
 		do_long = 1;
 		fmt = Tolower(fmt);
 	    }
@@ -206,7 +206,7 @@ doprnt(addchar, sfmt, ap)
 		break;
 
 	    case 'S':
-#ifdef SHORT_STRINGS
+	    case 'Q':
 		Bp = va_arg(ap, Char *);
 		if (!Bp) {
 		    bp = NULL;
@@ -217,21 +217,18 @@ doprnt(addchar, sfmt, ap)
 		    while (f_width-- > 0)
 			(*addchar) ((int) (pad | attributes));
 		for (i = 0; *Bp && i < prec; i++) {
-		    (*addchar) ((int) ((unsigned char)*Bp | attributes));
+		    if (fmt == 'Q' && *Bp & QUOTE)
+			(*addchar) ((int) ('\\' | attributes));
+		    (*addchar) ((int) ((*Bp & TRIM) | attributes));
 		    Bp++;
 		}
 		if (flush_left)
 		    while (f_width-- > 0)
 			(*addchar) ((int) (' ' | attributes));
 		break;
-#else
-		bp = va_arg(ap, Char *);
-		if (bp)
-		    (void) strip((Char *) bp);
-		goto lcase_s;
-#endif /* SHORT_STRINGS */
 
 	    case 's':
+	    case 'q':
 		bp = va_arg(ap, char *);
 lcase_s:
 		if (!bp)
@@ -241,13 +238,15 @@ lcase_s:
 		    while (f_width-- > 0)
 			(*addchar) ((int) (pad | attributes));
 		for (i = 0; *bp && i < prec; i++) {
-		    (*addchar) ((int) (((unsigned char) *bp) | attributes));
+		    if (fmt == 'q' && *bp & QUOTE)
+			(*addchar) ((int) ('\\' | attributes));
+		    (*addchar) ((int) (((unsigned char) *bp & TRIM) |
+				   	attributes));
 		    bp++;
 		}
 		if (flush_left)
 		    while (f_width-- > 0)
 			(*addchar) ((int) (' ' | attributes));
-
 		break;
 
 	    case 'a':
@@ -269,21 +268,24 @@ lcase_s:
 }
 
 
-static char *xstring;
+static char *xstring, *xestring;
 static void
 xaddchar(c)
     int     c;
 {
-    *xstring++ = (char) c;
+    if (xestring == xstring)
+	*xstring = '\0';
+    else
+	*xstring++ = (char) c;
 }
 
 
 pret_t
 /*VARARGS*/
 #ifdef FUNCPROTO
-xsprintf(char *str, const char *fmt, ...)
+xsnprintf(char *str, size_t size, const char *fmt, ...)
 #else
-xsprintf(va_alist)
+xsnprintf(va_alist)
     va_dcl
 #endif
 {
@@ -292,13 +294,16 @@ xsprintf(va_alist)
     va_start(va, fmt);
 #else
     char *str, *fmt;
+    size_t size;
 
     va_start(va);
     str = va_arg(va, char *);
+    size = va_arg(va, size_t);
     fmt = va_arg(va, char *);
 #endif
 
-    xstring = (char *) str;
+    xstring = str;
+    xestring = str + size - 1;
     doprnt(xaddchar, fmt, va);
     va_end(va);
     *xstring++ = '\0';
@@ -307,7 +312,6 @@ xsprintf(va_alist)
 #endif
 }
 
-
 pret_t
 /*VARARGS*/
 #ifdef FUNCPROTO
@@ -346,12 +350,14 @@ xvprintf(fmt, va)
 }
 
 pret_t
-xvsprintf(str, fmt, va)
+xvsnprintf(str, size, fmt, va)
     char   *str;
+    size_t size;
     const char   *fmt;
     va_list va;
 {
-    xstring = (char *) str;
+    xstring = str;
+    xestring = str + size - 1;
     doprnt(xaddchar, fmt, va);
     *xstring++ = '\0';
 #ifdef PURIFY
