@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.prompt.c,v 3.30 1998/04/08 17:57:35 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.prompt.c,v 3.34 1998/09/04 21:17:01 christos Exp $ */
 /*
  * tc.prompt.c: Prompt printing stuff
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.prompt.c,v 3.30 1998/04/08 17:57:35 christos Exp $")
+RCSID("$Id: tc.prompt.c,v 3.34 1998/09/04 21:17:01 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -46,7 +46,7 @@ RCSID("$Id: tc.prompt.c,v 3.30 1998/04/08 17:57:35 christos Exp $")
  * PWP 4/27/87 -- rearange for tcsh.
  * mrdch@com.tau.edu.il 6/26/89 - added ~, T and .# - rearanged to switch()
  *                 instead of if/elseif
- * Luke Mewburn, <lukem@connect.com.au>:
+ * Luke Mewburn, <lukem@cs.rmit.edu.au>
  *	6-Sep-91	changed date format
  *	16-Feb-94	rewrote directory prompt code, added $ellipsis
  *	29-Dec-96	added rprompt support
@@ -176,7 +176,8 @@ printprompt(promptno, str)
 void
 tprintf(what, buf, fmt, siz, str, tim, info)
     int what;
-    Char *buf, *fmt;
+    Char *buf;
+    const Char *fmt;
     size_t siz;
     char *str;
     time_t tim;
@@ -185,20 +186,21 @@ tprintf(what, buf, fmt, siz, str, tim, info)
     Char   *z, *q;
     Char    attributes = 0;
     static int print_prompt_did_ding = 0;
-    const unsigned char   *cz;
+    const char   *cz;
     Char    buff[BUFSIZE];
-    unsigned char    cbuff[BUFSIZE];
+    char    cbuff[BUFSIZE];
 
     Char *p  = buf;
     Char *ep = &p[siz];
-    Char *cp = fmt, Scp;
+    const Char *cp = fmt;
+    Char Scp;
     struct tm *t = localtime(&tim);
 
 			/* prompt stuff */
     static Char *olddir = NULL, *olduser = NULL;
     extern int tlength;	/* cache cleared */
-    size_t sz, pdirs;
-    int updirs;
+    int updirs, sz;
+    size_t pdirs;
 
     for (; *cp; cp++) {
 	if (p >= ep)
@@ -208,9 +210,9 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    switch (*cp) {
 	    case 'R':
 		if (what == FMT_HISTORY)
-		    fmthist('R', info, str = (char *) cbuff, sizeof(cbuff));
+		    fmthist('R', info, str = cbuff, sizeof(cbuff));
 		if (str != NULL)
-		    for (; *str; *p++ = attributes | (unsigned char) *str++)
+		    for (; *str; *p++ = attributes | *str++)
 			if (p >= ep) break;
 		break;
 	    case '#':
@@ -220,13 +222,13 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'h':
 		switch (what) {
 		case FMT_HISTORY:
-		    fmthist('h', info, cbuff, sizeof(cbuff));
+		    fmthist('h', info, (char *) cbuff, sizeof(cbuff));
 		    break;
 		case FMT_SCHED:
-		    (void) xsnprintf(cbuff, sizeof(cbuff), "%d", *(int *)info);
+		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", *(int *)info);
 		    break;
 		default:
-		    (void) xsnprintf(cbuff, sizeof(cbuff), "%d", eventno + 1);
+		    (void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", eventno + 1);
 		    break;
 		}
 		for (cz = cbuff; *cz; *p++ = attributes | *cz++)
@@ -306,7 +308,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'M':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO)
-		    cz = who_info(info, 'M', cbuff, sizeof(cbuff));
+		    cz = who_info(info, 'M', (char *) cbuff, sizeof(cbuff));
 		else 
 #endif /* HAVENOUTMP */
 		    cz = getenv("HOST");
@@ -322,7 +324,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'm':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO)
-		    cz = who_info(info, 'm', cbuff, sizeof(cbuff));
+		    cz = who_info(info, 'm', (char *) cbuff, sizeof(cbuff));
 		else 
 #endif /* HAVENOUTMP */
 		    cz = getenv("HOST");
@@ -364,6 +366,13 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 		    	*p++ = attributes | *z++;
 		    	*p++ = attributes | *z++;
 		    }
+			if (*z == '/' && z[1] == '/') {
+				*p++ = attributes | *z++;
+				*p++ = attributes | *z++;
+				do {
+					*p++ = attributes | *z++;
+				}while(*z != '/');
+			}
 #endif /* WINNT */
 		    q = z;
 		    while (*z)				/* calc # of /'s */
@@ -419,7 +428,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 			    *p++ = attributes | '+';
 			} else
 			    *p++ = attributes | ('0' + updirs);
-			*p++ = attributes | '>';
+			*p++ = attributes | tcsh ? '>' : '%';
 		    }
 		}
 		
@@ -431,7 +440,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'n':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO) {
-		    cz = who_info(info, 'n', cbuff, sizeof(cbuff));
+		    cz = who_info(info, 'n', (char *) cbuff, sizeof(cbuff));
 		    for (; cz && *cz ; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		}
@@ -446,7 +455,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    case 'l':
 #ifndef HAVENOUTMP
 		if (what == FMT_WHO) {
-		    cz = who_info(info, 'l', cbuff, sizeof(cbuff));
+		    cz = who_info(info, 'l', (char *) cbuff, sizeof(cbuff));
 		    for (; cz && *cz ; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		}
@@ -561,7 +570,7 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    default:
 #ifndef HAVENOUTMP
 		if (*cp == 'a' && what == FMT_WHO) {
-		    cz = who_info(info, 'a', cbuff, sizeof(cbuff));
+		    cz = who_info(info, 'a', (char *) cbuff, sizeof(cbuff));
 		    for (; cz && *cz; *p++ = attributes | *cz++)
 			if (p >= ep) break;
 		}
@@ -579,9 +588,9 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 	    *p++ = attributes | parseescape(&cp);
 	else if (*cp == HIST) {	/* EGS: handle '!'s in prompts */
 	    if (what == FMT_HISTORY) 
-		fmthist('h', info, cbuff, sizeof(cbuff));
+		fmthist('h', info, (char *) cbuff, sizeof(cbuff));
 	    else
-		(void) xsnprintf(cbuff, sizeof(cbuff), "%d", eventno + 1);
+		(void) xsnprintf((char *) cbuff, sizeof(cbuff), "%d", eventno + 1);
 	    for (cz = cbuff; *cz; *p++ = attributes | *cz++)
 		if (p >= ep) break;
 	}
@@ -594,13 +603,14 @@ tprintf(what, buf, fmt, siz, str, tim, info)
 Char *
 expdollar(dstp, srcp, spp, attr)
     Char **dstp;
-    Char **srcp;
+    const Char **srcp;
     size_t *spp;
     int	    attr;
 {
     struct varent *vp;
     Char var[MAXVARLEN];
-    Char *src = *srcp, *val;
+    const Char *src = *srcp;
+    Char *val;
     Char *dst = *dstp;
     int i, curly = 0;
 
